@@ -1,4 +1,4 @@
-class FoxtrotError(Exception):
+class FoxtrotError(RuntimeError):
   def __init__(self, message):
     super(FoxtrotError, self).__init__(message)
 
